@@ -24,6 +24,9 @@ except:
     pass
 
 
+#load language file
+import i18n
+_ = i18n.language.ugettext
 
 
 ###########################################################################
@@ -33,16 +36,17 @@ def SetAlarm():
     if(data.demo==False): #We are on a N900
         event = alarm.Event()
         event.appid = 'SleepAnalyser'
-        event.message = 'Wake up (SleepAnalyser)!'
+#        event.title = _('SleepAnalyser alarm')
+        event.message = _('Wake up (SleepAnalyser)')
 
         event.alarm_time = records.AlarmTime_seconds #in seconds
 
-        action_stop, action_snooze = event.add_actions(2)
-        action_stop.label = 'Stop'
+        action_snooze, action_stop = event.add_actions(2)
+        action_snooze.label = _('Snooze')
+        action_snooze.flags |= alarm.ACTION_WHEN_RESPONDED | alarm.ACTION_TYPE_SNOOZE
+        action_stop.label = _('Stop')
         action_stop.flags |= alarm.ACTION_WHEN_RESPONDED | alarm.ACTION_TYPE_NOP
 
-        action_snooze.label = 'Snooze'
-        action_snooze.flags |= alarm.ACTION_WHEN_RESPONDED | alarm.ACTION_TYPE_SNOOZE
 
         data.AlarmID = alarm.add_event(event)
 
@@ -56,6 +60,29 @@ def SetAlarm():
 
 
 
+###########################################################################
+## Delete al alarms with appid "SleepAnalyser"
+## When SleepAnalyser crashed, it is possible that there is still an (old) alarm  in the dbus alarm queue
+## This function deletes them all
+###########################################################################
+def delete_all_preexisting_Alarms():
+    print "* Search and delete all alarms from SleepAnalyser"
+    if(data.demo==False): #We are on a N900
+        event = alarm.query_event(0, 0, 0, 0, "") #get list of all set alarm in N900
+        i=0
+        for e in event:
+            e2=alarm.get_event(e)
+#            print time.ctime(e2.trigger), e2.appid, e2.message #print all alarms
+            if(e2.appid=="SleepAnalyser"): #filter our alarms
+#                print "Found one of our Alarms:", time.ctime(e2.trigger), e2.appid , e2.title, e2.message #print our alarms
+                alarm.delete_event(e)
+                i=i+1
+#                print "Deleted it"
+        if(i==0): print "* No old alarms found"
+        else: print "* Found", i, "of our alarms and deleted them"
+    else:
+        print "* Will not delete alarm, Maemo interface not available"
+
 
 
 
@@ -90,18 +117,23 @@ def DeleteAlarm():
 
 
 
+
+
 ###########################################################################
 ##
 ###########################################################################
 def ProcessAlarm():
     i=records.Index-data.Derivation
-    if(i>1): peak=records.arrData[4][i-1]
+#    if(i>1): peak=records.arrData[4][i-1] #check if last movement is over trigger level
+    if(i>1): peak=records.arrData[6][i-1] #New: use blue graph for triggering
     else: peak=0
     now=Tuple2Seconds(time.localtime())
-    if(peak>data.Trigger): #big Movement
+#    if(peak>data.Trigger): #big Movement
+    if(peak>(data.Trigger*data.FilterScale*3/40)): #Trigger Alarm
        if(records.AlarmIsSet==True and data.AlarmIsActive==False and now>=records.AlarmTimeWindowStart_seconds and now<records.AlarmTimeWindowEnd_seconds):
             #print big movement and we are in alarm time window, update alarm time, set alarm off
             print "************ ALARM ALARM (Movement over trigger level)"
+            print "*", strftime("%x %X"), "ProcessAlarm => DeleteAlarm" #for log file
             DeleteAlarm() #delete old alarm if existing
 #            h=int(strftime("%H", time.localtime()))
 #            m=int(strftime("%M", time.localtime()))
@@ -109,6 +141,7 @@ def ProcessAlarm():
 #            now=int(strftime("%H", time.localtime()))*3600+int(strftime("%M", time.localtime()))*60
             records.AlarmTime_tuple=time.localtime()#set to now
             records.AlarmTime_seconds=Tuple2Seconds(records.AlarmTime_tuple)
+            print "*", strftime("%x %X"), "ProcessAlarm => SetAlarm" #for log file
             SetAlarm() #set alarm to go off now
             records.Trigger=data.Trigger #update Trigger level on alarm occurence
             data.AlarmIsActive=True
@@ -123,4 +156,3 @@ def ProcessAlarm():
 #    print "records.AlarmIsSet", records.AlarmIsSet
 #    print "data.AlarmIsActive:",  data.AlarmIsActive
 #    print ""
-
