@@ -322,10 +322,10 @@ def LoadRecord():
     else: records.LastIndex=records.Index
 
     records.status=_("Data successful loaded")
-    print records.status
     records.statusID="OK"
 
     if(data.debug==True): PrintRecordData(False)
+    print "Data successful loaded"
     return 0 #all ok
 
 
