@@ -108,6 +108,11 @@ def LoadConfig():
     except:
         config.set('main', 'FilterScale', str(data.FilterScale))
 
+    try:
+        data.Sleep_Pattern_Yoffset = config.getint('main', 'Sleep_Pattern_Yoffset')
+    except:
+        config.set('main', 'Sleep_Pattern_Yoffset', str(data.Sleep_Pattern_Yoffset))
+
     try:
         data.limitMovement = config.getint('main', 'limitMovement')
     except:
