@@ -287,6 +287,9 @@ def MeasurementTimerLoop(): #(interval: sampling*sample_smoothing*value_smoothin
     if(data.AlarmIsActive==True): #alarm got activated
 #        print "Alarm is active"
         if(data.StopAfterAlarm==True): #stop recording
+
+            data.DisplayIsOn=True
+
 #            print "Stop measurement, alarm is active"
             print "Alarm got activated, stopped recording"
             txt=_("Alarm got activated, stopped recording")
@@ -299,12 +302,8 @@ def MeasurementTimerLoop(): #(interval: sampling*sample_smoothing*value_smoothin
             data.LastRecord=data.RecordFilename #set to corrent file for viewwindow
             config.set('main', 'LastRecord', str(data.LastRecord))
             print "Show record in ViewWindow:",  data.LastRecord
-            GenerateStatisticData()
-            ProcessData(False,  False)
-            Generate_Sleep_Pattern()
-            Generate_and_show_GraphBitmap(RecordWindow, True) #New: show blue graph
-            StartWindow.ShowViewWindow()
             RecordWindow.hide()
+            StartWindow.ShowViewWindow()
 
         else: #continue recording
             pass
@@ -314,8 +313,6 @@ def MeasurementTimerLoop(): #(interval: sampling*sample_smoothing*value_smoothin
 
 
 
-
-
 ###########################################################################
 ## Start the measurement
 ###########################################################################
@@ -447,7 +444,7 @@ def MoveTrigger(direction):
         if(data.Trigger>data.maxTrigger): data.Trigger=data.maxTrigger
     else: #-1, down
         data.Trigger=data.Trigger-1
-        if(data.Trigger<20): data.Trigger=20
+        if(data.Trigger<data.minTrigger): data.Trigger=data.minTrigger
     if(data.run==True): records.Trigger=data.Trigger
 
 
@@ -1054,16 +1051,19 @@ class frmViewWindow(QMainWindow):
             self.UpdateScreen()
             app.processEvents() #force ui update
 
-        self.ui.lblStatus.setText(_("Processessing data..."))
+        self.ui.lblStatus.setText(_("Processing data..."))
         app.processEvents() #force ui update
+        print "Processing data..."
         ProcessData(True, True)
 
         self.ui.lblStatus.setText(_("Rendering data..."))
         app.processEvents() #force ui update
+        print "Rendering data..."
         Generate_Sleep_Pattern()
 
         self.ui.lblStatus.setText(_("Generating statistic..."))
         app.processEvents() #force ui update
+        print "Generating statistic..."
 
         GenerateStatisticData()
 #        data.Xscale=1 #default zoom level
@@ -1073,12 +1073,12 @@ class frmViewWindow(QMainWindow):
 #        data.ChangesInGraph=True #Make sure it only gets refreshed once
 
         self.ui.lblStatus.hide()
-        self.Canvas.show()
-        self.StatisticsCanvas.show()
+        ViewWindow.Canvas.show()  #ViewWindow instead of self, as it gets executed in RecordWindow
+        ViewWindow.StatisticsCanvas.show() #ViewWindow instead of self, as it gets executed in RecordWindow
         Generate_and_show_GraphBitmap(self, True)
         GenerateStatisticsBitmap(self)
 
-    #Note: On the PC, the lable texts disappears here again until the window looses the focus, but it works fine on the N900, so I ignore it
+    #Note: On the PC, the lable texts disappears here again until the window looses the focus, but it works fine on the N900, so we ignore it
 
 
 
@@ -1238,7 +1238,8 @@ class frmViewWindow(QMainWindow):
         LoadFileList()
         self.ShowRecord()
         self.ui.lblStatus.hide()
-#        self.StatisticsCanvas.show()
+        ViewWindow.Canvas.show()
+        ViewWindow.StatisticsCanvas.show()
 
 
     ###########################################################################
